##  Activating the Scheduled Change Feature
To start using the scheduled change feature, it first needs to be activated in the administration area, and admin users have the right to activate or deactivate the feature.
To activate the scheduled change feature, do the following:
  1. Navigate to the Transformations section in the Administration area.
  2. In the Settings tab, you can toggle on the option to show scheduled changes.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiob011ddd9bd1a4e69a59f1600eebcfeb6_LowRes.png)
Activating the Scheduled Change Feature


Similarly, you can deactivate the feature if it is not needed.
